use axum::{routing::get, Router};

use std::sync::Arc;

use crate::{state::AppState, storages::StoragePool};

mod api;
mod config;
mod crypt;
mod routes;
mod state;
mod storages;

#[tokio::main]
async fn main() -> anyhow::Result<()> {
    tracing_subscriber::fmt::init();

    let config = config::load().await;
    let secret_key = config.secret_key.clone();

    let mut storage_pool = StoragePool::from_config(config.storages);
    storage_pool.init().await?;

    let app_state = AppState::new(storage_pool, secret_key);

    let app = Router::new()
        .route(
            "/*src",
            match app_state.secret_key {
                Some(_) => get(routes::handle_secure),
                None => get(routes::handle_unsecure),
            },
        )
        .with_state(Arc::new(app_state));

    let listener = tokio::net::TcpListener::bind("0.0.0.0:3100").await?;
    axum::serve(listener, app).await?;

    Ok(())
}
